
def upload_video(self, video, caption=''):
    self.small_delay()
    self.logger.info("Started uploading '{video}'".format(video=video))
    if not self.api.upload_video(video, caption):
        self.logger.info("Video '%s' is not %s ." % (video, 'uploaded'))
        return False
    self.logger.info("Video '{video}' uploaded".format(video=video))
    return True



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import os
import sys

import pytest

from .test_bot import TestBot


class TestBotSupport(TestBot):

    @pytest.mark.parametrize('url,result', [
        ('https://google.com', ['https://google.com']),
        ('google.com', ['google.com']),
        ('google.com/search?q=instabot', ['google.com/search?q=instabot']),
        ('https://google.com/search?q=instabot', ['https://google.com/search?q=instabot']),
        ('мвд.рф', ['мвд.рф']),
        ('https://мвд.рф', ['https://мвд.рф']),
        ('http://мвд.рф/news/', ['http://мвд.рф/news/']),
        ('hello, google.com/search?q=test and bing.com', ['google.com/search?q=test', 'bing.com']),
    ])
    def test_extract_urls(self, url, result):
        assert self.bot.extract_urls(url) == result

    def test_check_if_file_exist(self):
        test_file = open('test', 'w')

        assert self.bot.check_if_file_exists('test')

        test_file.close()
        os.remove('test')

    def test_check_if_file_exist_fail(self):
        assert not self.bot.check_if_file_exists('test')

    @pytest.mark.parametrize('verbosity,text,result', [
        (True, 'test', 'test'),
        (False, 'test', '')
    ])
    def test_console_print(self, verbosity, text, result):
        self.bot.verbosity = verbosity
        try:
            if sys.version_info > (3,):
                from io import StringIO
            else:
                from StringIO import StringIO
            saved_stdout = sys.stdout
            out = StringIO()
            sys.stdout = out

            self.bot.console_print(text)

            output = out.getvalue().strip()
            assert output == result
        finally:
            sys.stdout = saved_stdout




import pytest
import responses

try:
    from unittest.mock import patch
except ImportError:
    from mock import patch

from instabot.api.config import API_URL

from .test_bot import TestBot
from .test_variables import (TEST_CAPTION_ITEM, TEST_COMMENT_ITEM)


class TestBotGet(TestBot):

    @responses.activate
    @pytest.mark.parametrize('blocked_actions_protection,blocked_actions', [
        (True, True),
        (True, False),
        (False, True),
        (False, False)])
    @patch('time.sleep', return_value=None)
    def test_comment_feedback(self, patched_time_sleep, blocked_actions_protection, blocked_actions):
        self.bot.blocked_actions_protection = blocked_actions_protection
        self.bot.blocked_actions['comments'] = blocked_actions
        media_id = 1234567890
        comment_txt = "Yeah great!"

        TEST_COMMENT_ITEM['user']['pk'] = self.bot.user_id + 1

        results = 3
        response_data = {
            "caption": TEST_CAPTION_ITEM,
            "caption_is_edited": False,
            "comment_count": results,
            "comment_likes_enabled": True,
            "comments": [TEST_COMMENT_ITEM for _ in range(results)],
            "has_more_comments": False,
            "has_more_headload_comments": False,
            "media_header_display": "none",
            "preview_comments": [],
            "status": "ok"
        }
        responses.add(
            responses.GET, '{api_url}media/{media_id}/comments/?'.format(
                api_url=API_URL, media_id=media_id), json=response_data, status=200)

        response_data = {
            "message": "feedback_required",
            "spam": True,
            "feedback_title": "Sorry, this feature isn't available right now",
            "feedback_message": "An error occurred while processing this request. Please try again later. We restrict certain content and actions to protect our community. Tell us if you think we made a mistake.",
            "feedback_url": "repute/report_problem/instagram_comment/",
            "feedback_appeal_label": "Report problem",
            "feedback_ignore_label": "OK",
            "feedback_action": "report_problem",
            "status": "fail"}
        responses.add(
            responses.POST, '{api_url}media/{media_id}/comment/'.format(
                api_url=API_URL, media_id=media_id
            ), json=response_data, status=400
        )

        assert not self.bot.comment(media_id, comment_txt)

    @responses.activate
    @pytest.mark.parametrize('blocked_actions_protection,blocked_actions', [
        (True, False),
        (False, False)])
    @patch('time.sleep', return_value=None)
    def test_comment(self, patched_time_sleep, blocked_actions_protection, blocked_actions):
        self.bot.blocked_actions_protection = blocked_actions_protection
        self.bot.blocked_actions['comments'] = blocked_actions
        media_id = 1234567890
        comment_txt = "Yeah great!"

        TEST_COMMENT_ITEM['user']['pk'] = self.bot.user_id + 1

        results = 3
        response_data = {
            "caption": TEST_CAPTION_ITEM,
            "caption_is_edited": False,
            "comment_count": results,
            "comment_likes_enabled": True,
            "comments": [TEST_COMMENT_ITEM for _ in range(results)],
            "has_more_comments": False,
            "has_more_headload_comments": False,
            "media_header_display": "none",
            "preview_comments": [],
            "status": "ok"
        }
        responses.add(
            responses.GET, '{api_url}media/{media_id}/comments/?'.format(
                api_url=API_URL, media_id=media_id), json=response_data, status=200)

        response_data = {
            "status": "ok"}
        responses.add(
            responses.POST, '{api_url}media/{media_id}/comment/'.format(
                api_url=API_URL, media_id=media_id
            ), json=response_data, status=200
        )

        assert self.bot.comment(media_id, comment_txt)



import pytest
import responses

try:
    from unittest.mock import patch
except ImportError:
    from mock import patch

from instabot.api.config import API_URL

from .test_bot import TestBot
from .test_variables import TEST_USERNAME_INFO_ITEM


class TestBotFilter(TestBot):
    @pytest.mark.parametrize('filter_users,filter_business_accounts,filter_verified_accounts,expected', [
        (False, False, False, True),
        (True, False, False, True),
        (True, True, False, False),
        (True, False, True, False),
        (True, True, True, False),
    ])
    @responses.activate
    @patch('time.sleep', return_value=None)
    def test_check_user(self, patched_time_sleep, filter_users, filter_business_accounts, filter_verified_accounts, expected):
        self.bot.filter_users = filter_users
        self.bot.filter_business_accounts = filter_business_accounts
        self.bot.filter_verified_accounts = filter_verified_accounts
        self.bot._following = [1]

        user_id = TEST_USERNAME_INFO_ITEM['pk']
        TEST_USERNAME_INFO_ITEM['is_verified'] = True
        TEST_USERNAME_INFO_ITEM['is_business'] = True

        response_data = {
            'status': 'ok',
            'user': TEST_USERNAME_INFO_ITEM
        }
        responses.add(
            responses.GET, '{api_url}users/{user_id}/info/'.format(
                api_url=API_URL, user_id=user_id
            ), status=200, json=response_data)

        result = self.bot.check_user(user_id)

        assert result == expected
